modelinfo={
    "Cifar10":{
        "filename":"cifar10-80.h5",
        "repoid":"svnmurali1/cifar10-80",
        "classes":{0: 'airplane', 
                    1: 'automobile', 
                    2: 'bird', 
                    3: 'cat', 
                    4: 'deer', 
                    5: 'dog', 
                    6: 'frog', 
                    7: 'horse', 
                    8: 'ship', 
                    9: 'truck'},
        "metrics":{"accuracy":"80%"}
    },
    "GenderDetection":{
        "repoid":"svnmurali1/genderdetection",
        "filename":"genderdetection.h5",
        "classes":{
            0:"female",
            1:"male"
        },
        "metrics":{
            "accuracy":"90%"
        }
    },
    "FaceDetectionYolo":{
        "repoid":"svnmurali1/facedetectionyolo",
        "filename":"best.pt",
        "classes":{
            0:"face"
        },
        "metrics":{
            "accuracy":"90%"
        }
    }
    
}